BufferError

Enum BufferError 

#[non_exhaustive]
pub enum BufferError { AlignmentViolation, InsufficientData, StrideTooSmall, StrideNotPixelAligned, InvalidDimensions, IncompatibleDescriptor, AllocationFailed, }
Errors from pixel buffer operations.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


AlignmentViolation

Data pointer is not aligned for the channel type.



InsufficientData

Data slice is too small for the given dimensions and stride.



StrideTooSmall

Stride is smaller than width * bytes_per_pixel.



StrideNotPixelAligned

Stride is not a multiple of bytes_per_pixel.

Every row must start on a pixel boundary. If stride is not a multiple of bpp, rows after the first will be misaligned.



InvalidDimensions

Width or height is zero or causes overflow.



IncompatibleDescriptor

Descriptor bytes_per_pixel mismatch in reinterpret().

The new descriptor has a different bytes_per_pixel() than the current one, so reinterpreting the buffer would be invalid.



AllocationFailed

Buffer allocation failed (out of memory or overflow).